@@ -10,10 +10,13 @@ class TestModel(unittest.TestCase):
         self.data = tsag.preprocessing.PreprocessDatasets('prison').apply_preprocess()
         self.n = self.data['predict']['n']
         self.s = self.data['train']['s']
-        shutil.rmtree("./original_datasets")
-        shutil.rmtree("./transformed_datasets")
+        shutil.rmtree("./data/original_datasets")
         self.deepar = DeepAR(dataset='prison', groups=self.data)
 
+    @classmethod
+    def tearDownClass(cls):
+        shutil.rmtree("./results")
+
     def test_correct_train(self):
         model = self.deepar.train(epochs=10)
         self.assertIsNotNone(model)
@@ -29,4 +32,4 @@ class TestModel(unittest.TestCase):
         forecasts = self.deepar.predict(model)
         results = self.deepar.results(forecasts)
         res = self.deepar.metrics(results)
-        self.assertLess(res['mase']['bottom'], 2.5)
+        self.assertLess(res['mase']['bottom'], 2.8)
